pub trait Lower<O: Level>: Level { }Expand description
Indicate that the implementor is lower that the level O
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Lower<O: Level>: Level { }Indicate that the implementor is lower that the level O
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".